const lightCodeTheme = require("prism-react-renderer/themes/github");
const darkCodeTheme = require("prism-react-renderer/themes/dracula");

/** @type {import('@docusaurus/types').DocusaurusConfig} */
module.exports = {
  title: "Forggit.fr",
  tagline: "Froggit aide à booster la coopération des Dev, Ops et autres Techs des entreprises autour du code source, sans gérer une infrastructure complexe !",
  url: "https://new.froggit.fr",
  baseUrl: "/",
  onBrokenLinks: "throw",
  onBrokenMarkdownLinks: "warn",
  favicon: "img/favicon/favicon.ico",
  organizationName: "facebook", // Usually your GitHub org/user name.
  projectName: "docusaurus", // Usually your repo name.
  themeConfig: {
    navbar: {
      title: "Froggit",
      logo: {
        alt: "My Site Logo",
        src: "img/logo_froggit.svg",
      },
      items: [      
        {to: "/#features", label: "Fonctionnalités", position: "left"},
        {to: "/faq", label: "FAQ", position: "left"},
        {to: "/dummy_page", label: "Tarifs", position: "left"},
        {to: "/blog", label: "Blog", position: "left"},        
        {type: "doc", docId: "intro", position: "left", label: "Doc",},
        {
          href: "https://lab.frogg.it/users/sign_in",
          label: "Connexion",
          position: "right",
        },
        {to: "/dummy_page", label: "S'enregister", position: "right"},
      ],
    },
    footer: {
      style: "dark",
      links: [
        {
          title: "Suivez-nous",
          items: [
            {
              label: "Youtube",
              href: "https://www.youtube.com/channel/UCauIDghddUNu6Fto1nR9Bmg/?sub_confirmation=1",
            },
            {
              label: "Linkedin",
              href: "https://www.linkedin.com/company/froggit",
            },
            {
              label: "Froggit",
              href: "https://lab.frogg.it/froggit",
            },
            {
              label: "GitLab",
              href: "https://gitlab.com/froggit",
            },
            {
              label: "Twitter",
              href: "https://twitter.com/art_devops",
            },
          ],
        },
          
        {
          title: "Pourquoi Froggit ?",
          items: [
            {
              label: "Ton code source est-il en sécurité?",
              href: "https://lydra.fr/es-2-ton-code-source-est-il-vraiment-en-securite/",
            },
            {
              label: "La souveraineté numérique",
              href: "https://lydra.fr/category/souverainete-numerique/",
            },
          ],
        },
        {
          title: "Communauté",
          items: [
            {
              label: "Forum",
              to: "/dummy_page",
            },
            {
              label: "Wiki",
              to: "/dummy_page",
            },
          ],
        },     
        {
          title: "Société",
          items: [
            {
              label: "À propos",
              to: "/dummy_page",
            },
            {
              label: "Contact",
              to: "/dummy_page",
            },
            {
              label: "Équipe",
              to: "/dummy_page",
            },
            {
              label: "Mentions légales",
              to: "/dummy_page",
            },
            {
              label: "CGV",
              href: "https://oxalis-scop.fr/conditions-generales-de-vente",
            },
            {
              label: "CPV",
              to: "/dummy_page",
            },
            {
              label: "CGU",
              to: "/dummy_page",
            },
          ],
        },
      ],
      
      // eslint-disable-next-line quotes
      copyright: `Lydra © ${new Date().getFullYear()}` +"<br>"+ `Froggit est fièrement fabriqué avec ❤️ par <a href="http://lydra.fr/">Lydra</a> avec des Logiciels Libres et hébergé en 🇫🇷 chez <a href="https://www.scaleway.fr/">Scaleway</a> | <a href="https://status.froggit.fr">✔️ Status du service</a>`,
    },
    prism: {
      theme: lightCodeTheme,
      darkTheme: darkCodeTheme,
    },
  },
  presets: [
    [
      "@docusaurus/preset-classic",
      {
        docs: {
          sidebarPath: require.resolve("./sidebars.js"),
          // Please change this to your repo.
          editUrl:
            "https://github.com/facebook/docusaurus/edit/master/website/",
        },
        blog: {
          showReadingTime: true,
          // Please change this to your repo.
          editUrl:
            "https://github.com/facebook/docusaurus/edit/master/website/blog/",
        },
        theme: {
          customCss: require.resolve("./src/css/custom.css"),
        },
      },
    ],
  ],
};
